======================
Another Sudoku Library
======================


.. image:: https://img.shields.io/pypi/v/another_sudoku_library.svg
        :target: https://pypi.python.org/pypi/another_sudoku_library

.. image:: https://img.shields.io/travis/jc400/another_sudoku_library.svg
        :target: https://travis-ci.com/jc400/another_sudoku_library

.. image:: https://readthedocs.org/projects/another-sudoku-library/badge/?version=latest
        :target: https://another-sudoku-library.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Library for generating and solving Sudoku puzzles.


* Free software: MIT license
* Documentation: https://another-sudoku-library.readthedocs.io.


Features
--------

* Generate new, random puzzles
* Solve puzzles 
* Check correctness of puzzles

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
